==> ped-2.0.0.tar.gz: lbc-1.1.0/external/prebuild.sh <==
#!/bin/sh
cat << 'EEE' > /dev/null
/* Copyright (C) 2021 Momi-g
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
EEE

set -eu	#exit 1 if anycmd rtns $? = 1
(
pdir=`pwd`	#parent, callsrc dir
cd `dirname $0`	#base $0 dir
bdir=`pwd`
cd ../
topdir=`pwd`	#configure root
test -d ./exdir || mkdir -p exdir
cd $bdir

v_afiles=`ls *.tar.gz *.zip 2>/dev/null || :`
[ ${#v_afiles} != 0 ] || exit 0

for v_afile in $v_afiles;do
	conflg=0
	cd $bdir
	v_dname=${v_afile%.tar.gz}
	v_dname=${v_dname%.zip}
	ucmd="tar -xf $v_afile"
	[ "$v_dname" = "${v_afile%.tar.gz}" ] || ucmd="unzip $v_afile"
	[ "../$v_dname" -nt "$v_afile" ] && continue ||
	{
		cp $v_afile ../
		cd ../
		rm -rf "$v_dname"
		eval "$ucmd"
		touch "$v_dname"
		conflg=1
		rm $v_afile 2>/dev/null||:
		cd $bdir
	}
	cd ../$v_dname
# [ ${v_afile#app123} != $v_afile ] && make,cp,remove,ls,copy etc. not autotool pkg
	case "$v_dname" in
	LuaJIT*)
		# [ $conflg = 0 ] || ./configure
		make amalg CFLAGS="-fPIC"
		make DESTDIR="$topdir/exdir" install
		buf=`find ./ \
			-name 'libluajit-*.a'	\
		-o -name lauxlib.h          \
		-o -name lua.h              \
		-o -name luaconf.h          \
		-o -name luajit.h           \
		-o -name lualib.h           \
		-o -name lj_arch.h          \
		`
		[ "$buf" != "" ] || ! echo "prebuild failed, $0" >/dev/stderr
		for i in $buf;do
			cp $i $topdir/exdir
		done
	;;
#	bootlj*)
#		[ $conflg = 0 ] || ./configure
#		make
#		make DESTDIR="$topdir/exdir" install
#	;;
	*)
		echo "unreachable code, $0" >/dev/stderr
		exit 1
	;;
	esac
done
cd "$topdir/exdir"	
buf=`find ./	\
	-name '*.a'		\
-o	-name '*.h'		\
`
for i in $buf;do
	cp $i ../src
done
# mv ../../src/libluajit.a ../../src/libluajit_e.a
)

==> ped-2.1.2.tar.gz: lbc-1.2.0/external/prebuild.sh <==
#!/bin/sh
cat << 'EEE' > /dev/null
/* Copyright (C) 2021 Momi-g
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
EEE

set -eu	#exit 1 if anycmd rtns $? = 1
(
pdir=`pwd`	#parent, callsrc dir
cd `dirname $0`	#base $0 dir
bdir=`pwd`
cd ../
topdir=`pwd`	#configure root
test -d ./exdir || mkdir -p exdir
cd $bdir

v_afiles=`ls *.tar.gz *.zip 2>/dev/null || :`
[ ${#v_afiles} = 0 ] && exit 0

for v_afile in $v_afiles;do
	conflg=0
	cd $bdir
	v_dname=${v_afile%.tar.gz}
	v_dname=${v_dname%.zip}
	ucmd="tar -xf $v_afile"
	[ "$v_dname" = "${v_afile%.tar.gz}" ] || ucmd="unzip $v_afile"
	[ "../$v_dname" -nt "$v_afile" ] ||
	{
		cp $v_afile ../
		cd ../
		rm -rf "$v_dname"
		eval "$ucmd"
		buf=`find ./ -type d -name "$v_dname*"`
		mv "$buf" "$v_dname"||:
		touch "$v_dname"
		conflg=1
		rm $v_afile 2>/dev/null||:
		cd $bdir
	}
	cd ../$v_dname*
# [ ${v_afile#app123} != $v_afile ] && make,cp,remove,ls,copy etc. not autotool pkg
	case "$v_dname" in
	LuaJIT*)
		# [ $conflg = 0 ] || ./configure
		make amalg CFLAGS="-fPIC"
		make DESTDIR="$topdir/exdir" install
		
		buf=`find ./ -name luajit|head -n 1`
		[ "$buf" = "" ] && echo "prebuild failed, $0" >/dev/stderr && exit 1
		cp $buf $topdir/exdir
#		buf=`find ./ \
#			-name 'libluajit-*.a'	\
#		-o -name lauxlib.h          \
#		-o -name lua.h              \
#		-o -name luaconf.h          \
#		-o -name luajit.h           \
#		-o -name lualib.h           \
#		-o -name lj_arch.h          \
#		-o -name luajit             \
#		`
#		[ "$buf" = "" ] && echo "prebuild failed, $0" >/dev/stderr && exit 1
#		for i in $buf;do
#			cp $i $topdir/exdir
#		done
	;;
	txt2lit*)
		[ -f Makefile ] || ./configure
		make
		make DESTDIR="$topdir/exdir" install
	;;
#	bootlj*)
#		[ $conflg = 0 ] || ./configure
#		make
#		make DESTDIR="$topdir/exdir" install
#	;;
	*)
		echo "unreachable code, $0" >/dev/stderr
		exit 1
	;;
	esac
done
cd "$topdir/exdir"

buf=`find ./	\
	-name 'libluajit-*.a'	\
-o	-name lauxlib.h         \
-o	-name lua.h             \
-o	-name luaconf.h         \
-o	-name luajit.h          \
-o	-name lualib.h          \
-o	-name luajit            \
							\
-o	-name 'txt2lit'			\
-o	-name 'txt2lit.1'		\
-o	-name 'txt2lit.1.html'	\
`
for i in $buf;do
	cp $i ../src
done
mv -f ../src/luajit ../src/luajit_
# mv ../../src/libluajit.a ../../src/libluajit_e.a
)
